California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 37 - FEES. VOTE REQUIREMENTS. TAXES. INITIATIVE CONSTITUTIONAL AMENDMENT. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
992080 | CALIFORNIANS AGAINST HIDDEN TAXES, YES ON PROPOSITION 37, A COALITION OF TAXPAYERS, CONSUMERS, BUSINESS AND FARMERS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1226395 | CHEMICAL INDUSTRY COUNCIL OF CALIFORNIA ISSUES PAC, YES ON 37 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1229739 | CALIFORNIA PUBLIC INTEREST RESEARCH GROUP | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1228025 | TAXPAYERS AGAINST POLLUTER PROTECTION, NO ON 37 | OPPOSE